@@ -39,6 +39,8 @@ fn get_relevant_event_kind(event_kind: &EventKind) -> Option<SimpleFileSystemEve
             Some(SimpleFileSystemEventKind::Create)
         }
         EventKind::Modify(ModifyKind::Data(_))
+        // Windows 10 only reports modify events at the `Any` granularity.
+        | EventKind::Modify(ModifyKind::Any)
         // Intellij modifies file metadata on edit.
         // https://github.com/passcod/notify/issues/150#issuecomment-494912080
         | EventKind::Modify(ModifyKind::Metadata(MetadataKind::WriteTime))
@@ -82,6 +84,12 @@ pub fn filter_events(
         }
         let path = event.event.paths[0].clone();
 
+        // Since we debounce things, some files might already not exist anymore by the
+        // time we get to them
+        if !path.exists() {
+            continue;
+        }
+
         if is_ignored_file(ignored_content_globset, &path) {
             continue;
         }
@@ -172,6 +180,7 @@ mod tests {
         let cases = vec![
             (EventKind::Create(CreateKind::File), Some(SimpleFileSystemEventKind::Create)),
             (EventKind::Create(CreateKind::Folder), Some(SimpleFileSystemEventKind::Create)),
+            (EventKind::Modify(ModifyKind::Any), Some(SimpleFileSystemEventKind::Modify)),
             (
                 EventKind::Modify(ModifyKind::Data(DataChange::Size)),
                 Some(SimpleFileSystemEventKind::Modify),
@@ -226,6 +235,7 @@ mod tests {
             Path::new("hello.html~"),
             Path::new("#hello.html"),
             Path::new(".index.md.kate-swp"),
+            Path::new("smtp.md0HlVyu.bck"),
         ];
 
         for t in test_cases {
